@@ -28,6 +28,8 @@
 #include <QQmlContext>
 #include <QQuickItem>
 
+static QString s_selectedStyle;
+
 QUrl KirigamiPlugin::componentUrl(const QString &fileName) const
 {
     foreach (const QString &style, m_stylesFallbackChain) {
@@ -45,12 +47,16 @@ void KirigamiPlugin::registerTypes(const char *uri)
     Q_ASSERT(uri == QLatin1String("org.kde.kirigami"));
     const QString style = QString::fromLatin1(qgetenv("QT_QUICK_CONTROLS_STYLE"));
 
-#if !defined(Q_OS_ANDROID) && !defined(Q_OS_IOS)
     //org.kde.desktop.plasma is a couple of files that fall back to desktop by purpose
     if ((style.isEmpty() || style == QStringLiteral("org.kde.desktop.plasma")) && QFile::exists(resolveFilePath(QStringLiteral("/styles/org.kde.desktop")))) {
+#if !defined(Q_OS_ANDROID) && !defined(Q_OS_IOS)
         m_stylesFallbackChain.prepend(QStringLiteral("org.kde.desktop"));
-    }
+#elif defined(Q_OS_ANDROID)
+        m_stylesFallbackChain.prepend(QStringLiteral("material"));
+#else // do we have an iOS specific style?
+        m_stylesFallbackChain.prepend(QStringLiteral("material"));
 #endif
+    }
 
     if (!style.isEmpty() && QFile::exists(resolveFilePath(QStringLiteral("/styles/") + style))) {
         m_stylesFallbackChain.prepend(style);
@@ -64,10 +70,12 @@ void KirigamiPlugin::registerTypes(const char *uri)
 
     //TODO: in this plugin it will end up something similar to
     //PlasmaCore's ColorScope?
-
+    s_selectedStyle = m_stylesFallbackChain.first();
     qmlRegisterSingletonType<Settings>(uri, 2, 0, "Settings",
          [](QQmlEngine*, QJSEngine*) -> QObject* {
-             return new Settings;
+             Settings *settings = new Settings;
+             settings->setStyle(s_selectedStyle);
+             return settings;
          }
      );
 
@@ -99,6 +107,8 @@ void KirigamiPlugin::registerTypes(const char *uri)
 #endif
 
     qmlRegisterType(componentUrl(QStringLiteral("Label.qml")), uri, 2, 0, "Label");
+    //TODO: uncomment for 2.3 release
+    //qmlRegisterTypeNotAvailable(uri, 2, 3, "Label", "Label type not supported anymore, use QtQuick.Controls.Label 2.0 instead");
     qmlRegisterType(componentUrl(QStringLiteral("OverlaySheet.qml")), uri, 2, 0, "OverlaySheet");
     qmlRegisterType(componentUrl(QStringLiteral("Page.qml")), uri, 2, 0, "Page");
     qmlRegisterType(componentUrl(QStringLiteral("ScrollablePage.qml")), uri, 2, 0, "ScrollablePage");
